@@ -1,10 +1,11 @@
-from .blocks import ConcatenateFeatures, DeaggregateNanopolish, Flatten, KmerMultipleEmbedding, Linear
+from .blocks import ConcatenateFeatures, DeaggregateNanopolish, Flatten, KmerMultipleEmbedding, Linear, ExtractSignal
 from .pooling_blocks import SummaryStatsAggregator, ProbabilityAttention, SummaryStatsProbability, MeanAggregator
 from .pooling_blocks import Attention, GatedAttention, KDELayer, KDEAttentionLayer, KDEGatedAttentionLayer
 from .pooling_blocks import SigmoidMaxPooling, SigmoidMeanPooling, SigmoidProdPooling
 
 
 __all__ = [
-    'ConcatenateFeatures', 'DeaggregateNanopolish', 'Flatten', 'KmerMultipleEmbedding', 'Linear', 'SummaryStatsAggregator', 'ProbabilityAttention', 'SummaryStatsProbability',
+
+    'ConcatenateFeatures', 'DeaggregateNanopolish', 'Flatten', 'ExtractSignal', 'KmerMultipleEmbedding', 'Linear', 'SummaryStatsAggregator', 'ProbabilityAttention', 'SummaryStatsProbability',
     'Attention', 'GatedAttention', 'KDELayer', 'KDEAttentionLayer', 'KDEGatedAttentionLayer', 'SigmoidMaxPooling', 'SigmoidMeanPooling', 'SigmoidProdPooling', 'MeanAggregator'
 ]
